@@ -169,6 +169,11 @@ def test_search_object(mock_simbad, db):
     t = db.search_object('engu', fuzzy_search=False)
     assert len(t) == 0
 
+    # Test pandas conversion
+    t = db.search_object('engu', fmt='pandas')
+    assert isinstance(t, pd.DataFrame)
+    assert 'source' in t.columns  # check column names
+
     # Search but only consider the Sources.source column
     t = db.search_object('penguin', table_names={'Sources': ['source']})
     assert len(t) == 0
@@ -187,6 +192,16 @@ def test_search_object(mock_simbad, db):
         t = db.search_object('fake', table_names={'NOTABLE': ['nocolumn']})
 
 
+def test_search_string(db):
+    d = db.search_string('fake')
+    assert len(d['Sources']) > 0
+    assert d['Sources']['source'] == 'FAKE'
+    d = db.search_string('2mass', fuzzy_search=True)
+    assert len(d) > 0
+    d = db.search_string('2mass', fuzzy_search=False)
+    assert len(d) == 0
+
+
 def test_query_region(db):
     t = db.query_region(SkyCoord(0, 0, frame='icrs', unit='deg'))
     assert len(t) == 0, 'Found source around 0,0 when there should be none'
